#!/usr/bin/ruby
# encoding: utf-8

class RescueScreen

	def initialize(layers, fixed)
		@layers = layers
		@fixed = fixed
		@source_combo = nil
		@target_combo = nil 
		@vte = nil
		lang = ENV['LANGUAGE'][0..1]
		lang = ENV['LANG'][0..1] if lang.nil?
		lang = "en" if lang.nil?
		@tl = MfsTranslator.new(lang, "RescueScreen.xml") 
		@start_label = @tl.get_translation("start_label") 
		create_first_layer 
		create_progress_layer
		create_vte_layer
		create_settings_layer 
	end
	attr_reader :start_label
	
	def create_first_layer
		bgimg = Gtk::Image.new("background.png")
		fx = Gtk::Fixed.new
		cancel = Gtk::Button.new(Gtk::Stock::CANCEL) 
		ok = Gtk::Button.new(Gtk::Stock::APPLY)
		set = Gtk::Button.new(Gtk::Stock::PREFERENCES) 
		fx.put(bgimg, 0, 0)
		# Label
		infolabel = Gtk::Label.new
		infolabel.wrap = true
		infolabel.width_request = 730
		infolabel.set_markup(@tl.get_translation("rescue_start")) 
		fx.put(infolabel, 250, 100)
		# Source
		source_label = Gtk::Label.new(@tl.get_translation("source") )
		@source_combo = Gtk::ComboBox.new
		@source_combo.width_request = 730
		@source_combo.height_request = 32
		fx.put(@source_combo, 250, 240)
		fx.put(source_label, 250, 208)
		# Target
		target_label = Gtk::Label.new(@tl.get_translation("target") )
		@target_combo = Gtk::ComboBox.new
		@target_combo.width_request = 730
		@target_combo.height_request = 32
		fx.put(@target_combo, 250, 320)
		fx.put(target_label, 250, 288)
		[ ok, cancel, set ].each { |w|
			w.width_request = 128
			w.height_request = 32 
		}
		cancel.signal_connect("clicked") { 
			@layers.each { |k,v| v.hide_all }
			@layers["start"].show_all 
		}
		ok.signal_connect("clicked") { 
			@layers.each { |k,v| v.hide_all }
			@layers["rescue_running"].show_all 
		}
		set.signal_connect("clicked") { 
			@layers.each { |k,v| v.hide_all }
			@layers["rescue_settings"].show_all 
		}
		fx.put(ok, OK_X, OK_Y)
		fx.put(cancel, CANCEL_X, CANCEL_Y)
		fx.put(set, SETTINGS_X, SETTINGS_Y)
		@fixed.put(fx, 0, 0)
		@layers["rescue_start"] = fx
	end
	
	def create_progress_layer
		bgimg = Gtk::Image.new("background.png")
		fx = Gtk::Fixed.new
		cancel = Gtk::Button.new(Gtk::Stock::CANCEL) 
		ok = Gtk::Button.new(Gtk::Stock::OK)
		ok.sensitive = false
		details = Gtk::Button.new(@tl.get_translation("details") )
		fx.put(bgimg, 0, 0)
		# Label
		infolabel = Gtk::Label.new
		infolabel.wrap = true
		infolabel.width_request = 730
		infolabel.set_markup(@tl.get_translation("rescue_running"))
		fx.put(infolabel, 250, 100)
		# Progress Bar
		pgbar = Gtk::ProgressBar.new
		pgbar.fraction = 0.3 
		pgbar.width_request = 594
		pgbar.height_request = 32
		fx.put(pgbar, 250, 240)
		fx.put(details, 852, 240)
		cancel.signal_connect("clicked") { 
			@layers.each { |k,v| v.hide_all }
			@layers["start"].show_all 
		}
		details.signal_connect("clicked") { 
			@layers.each { |k,v| v.hide_all }
			@layers["rescue_vte"].show_all 
		}
		[ ok, cancel, details ].each { |w|
			w.width_request = 128
			w.height_request = 32 
		}
		fx.put(ok, OK_X, OK_Y)
		fx.put(cancel, CANCEL_X, CANCEL_Y)
		@fixed.put(fx, 0, 0)
		@layers["rescue_running"] = fx
	end
	
	def reread_drivelist 
		1000.downto(0) { |n|
			begin
				@target_combo.remove_text(n)
			rescue
			end
			begin
				@source_combo.remove_text(n)
			rescue
			end
		}
		drives = Array.new
		partitions = Array.new
		Dir.entries("/sys/block").each { |l|
			drives.push(MfsDiskDrive.new(l, false)) if l =~ /[a-z]$/ ||  l =~ /mmcblk[0-9]$/ ||  l =~ /mmcblk[0-9][0-9]$/
		}
		drives.reverse.each { |d|
			label = "#{d.vendor} #{d.model}"
			if d.usb == true
				label = label + " (USB) "
			else
				label = label + " (SATA/eSATA/IDE) "
			end
			@source_combo.append_text(label)
			d.partitions.each  { |p|
				label = "#{d.vendor} #{d.model}"
				if d.usb == true
					label = label + " (USB) "
				else
					label = label + " (SATA/eSATA/IDE) "
				end
				label = label + "#{p.device} #{p.human_size}"
				label = @tl.get_translation("backup_medium") + " " + label if p.label.to_s == "USBDATA"
				pmnt = p.mount_point
				if ( p.fs =~ /vfat/ || p.fs =~ /ntfs/ || p.fs =~ /ext/ || p.fs =~ /btrfs/ ) && pmnt.nil?
					label = label + " #{p.fs}"
					partitions.push p.device
					@target_combo.append_text(label)
					@source_combo.append_text("    "+ label)
				end
			}
		}
		@target_combo.active = 0
		@source_combo.active = 0
	end
	
	def create_settings_layer
		bgimg = Gtk::Image.new("background.png")
		fx = Gtk::Fixed.new
		ok = Gtk::Button.new(Gtk::Stock::APPLY)
		fx.put(bgimg, 0, 0)
		# Label
		infolabel = Gtk::Label.new
		infolabel.wrap = true
		infolabel.width_request = 730
		infolabel.set_markup("rescue_settings")
		fx.put(infolabel, 250, 100)
		fvbox = Gtk::VBox.new(false, 6)
		# frame for method
		frames = Array.new
		frames[0] = Gtk::Frame.new("file-types")
		frames[1] = Gtk::Frame.new("search-opts")
		mvbox = Gtk::VBox.new(false, 6)
		frames[0].add mvbox 
		ok.signal_connect("clicked") { 
			@layers.each { |k,v| v.hide_all }
			@layers["rescue_start"].show_all 
		}
		[ ok ].each { |w|
			w.width_request = 128
			w.height_request = 32 
		}
		frames.each { |f|
			f.width_request = 740
			fvbox.pack_start_defaults(f)
		}
		fx.put(fvbox, 250, 140) 
		fx.put(ok, OK_X, OK_Y)
		@fixed.put(fx, 0, 0)
		@layers["rescue_settings"] = fx
	end
	
	def create_vte_layer
		bgimg = Gtk::Image.new("background.png")
		fx = Gtk::Fixed.new
		ok = Gtk::Button.new(Gtk::Stock::OK)
		ok.sensitive = true
		fx.put(bgimg, 0, 0)
		# Label
		infolabel = Gtk::Label.new
		infolabel.wrap = true
		infolabel.width_request = 730
		infolabel.set_markup(@tl.get_translation("rescue_vte"))
		fx.put(infolabel, 250, 100)
		# terminal
		@vte = Vte::Terminal.new
		@vte.set_font("Fixed 13", Vte::TerminalAntiAlias::FORCE_DISABLE)
		@vte.width_request = 730
		@vte.height_request = 250
		fx.put(@vte, 250, 250)
		[ ok ].each { |w|
			w.width_request = 128
			w.height_request = 32 
		}
		ok.signal_connect("clicked") { 
			@layers.each { |k,v| v.hide_all }
			@layers["rescue_running"].show_all 
		}
		fx.put(ok, OK_X, OK_Y)
		@fixed.put(fx, 0, 0)
		@layers["rescue_vte"] = fx
	end
	
end
